<?php

namespace Drupal\ytarget\Plugin\WebformHandler;

use Drupal\Core\Form\FormStateInterface;
use Drupal\webform\Plugin\WebformHandlerBase;
use Drupal\webform\Plugin\WebformHandlerInterface;
use Drupal\webform\WebformInterface;
use Drupal\webform\WebformSubmissionInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Yandex target goal handler.
 *
 * @WebformHandler(
 *   id = "ytarget",
 *   label = @Translation("Yandex target goal"),
 *   category = @Translation("SEO"),
 *   description = @Translation("Trigger Yandex Target goal."),
 *   cardinality = \Drupal\webform\Plugin\WebformHandlerInterface::CARDINALITY_UNLIMITED,
 *   submission = \Drupal\webform\Plugin\WebformHandlerInterface::SUBMISSION_OPTIONAL,
 *   results = FALSE,
 *   tokens = FALSE,
 * )
 */
class  YtargetWebformHandler extends WebformHandlerBase implements WebformHandlerInterface {

  /**
   * The Config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface.
   */
  protected $configFactory;

  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->configFactory = $container->get('config.factory');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
        'goal_name' => '',
      ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['goal_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Goal name'),
      '#default_value' => $this->configuration['goal_name'],
      '#required' => TRUE,
    ];
    return parent::buildConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['goal_name'] = $form_state->getValue('goal_name');
    parent::submitConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function alterForm(array &$form, FormStateInterface $form_state, WebformSubmissionInterface $webform_submission = NULL) {
    $form['#attached']['library'][] = 'ytarget/goal';
    $config = $this->configFactory->get('ytarget.settings');
    $metrikaId = $config->get('ytarget_id');
    $goal_name = $this->configuration['goal_name'];
    $form['#attributes']['data-ytarget-goal'] = $goal_name;
    $form['#attributes']['data-ytarget-mid'] = $metrikaId;
  }

  /**
   * {@inheritdoc}
   */
  public function isApplicable(WebformInterface $webform) {
    $config = $this->configFactory->get('ytarget.settings');
    $metrikaId = $config->get('ytarget_id');
    return !empty($metrikaId) && parent::isApplicable($webform);
  }

}
